package com.ruoyi.framework.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.system.mapper.FollowUpRecordsMapper;
import com.ruoyi.framework.system.domain.FollowUpRecords;
import com.ruoyi.framework.system.service.IFollowUpRecordsService;

/**
 * 随访记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-13
 */
@Service
public class FollowUpRecordsServiceImpl implements IFollowUpRecordsService 
{
    @Autowired
    private FollowUpRecordsMapper followUpRecordsMapper;

    /**
     * 查询随访记录
     * 
     * @param RecordID 随访记录主键
     * @return 随访记录
     */
    @Override
    public FollowUpRecords selectFollowUpRecordsByRecordID(Long RecordID)
    {
        return followUpRecordsMapper.selectFollowUpRecordsByRecordID(RecordID);
    }

    /**
     * 查询随访记录列表
     * 
     * @param followUpRecords 随访记录
     * @return 随访记录
     */
    @Override
    public List<FollowUpRecords> selectFollowUpRecordsList(FollowUpRecords followUpRecords)
    {
        return followUpRecordsMapper.selectFollowUpRecordsList(followUpRecords);
    }

    /**
     * 新增随访记录
     * 
     * @param followUpRecords 随访记录
     * @return 结果
     */
    @Override
    public int insertFollowUpRecords(FollowUpRecords followUpRecords)
    {
        return followUpRecordsMapper.insertFollowUpRecords(followUpRecords);
    }

    /**
     * 修改随访记录
     * 
     * @param followUpRecords 随访记录
     * @return 结果
     */
    @Override
    public int updateFollowUpRecords(FollowUpRecords followUpRecords)
    {
        return followUpRecordsMapper.updateFollowUpRecords(followUpRecords);
    }

    /**
     * 批量删除随访记录
     * 
     * @param RecordIDs 需要删除的随访记录主键
     * @return 结果
     */
    @Override
    public int deleteFollowUpRecordsByRecordIDs(Long[] RecordIDs)
    {
        return followUpRecordsMapper.deleteFollowUpRecordsByRecordIDs(RecordIDs);
    }

    /**
     * 删除随访记录信息
     * 
     * @param RecordID 随访记录主键
     * @return 结果
     */
    @Override
    public int deleteFollowUpRecordsByRecordID(Long RecordID)
    {
        return followUpRecordsMapper.deleteFollowUpRecordsByRecordID(RecordID);
    }
}
